# HelpDeskBot

Utility bot for Discord written in Python 3

## Project Home Page

https://www.devdungeon.com/content/help-desk-bot

## Installation

```bash
pip install helpdeskbot
```

## Updating

```bash
pip install --upgrade helpdeskbot --no-cache-dir
```

## Running

Execute `helpdeskbot` and it will load the token and
channel name from the `.env` file. Create the `.env`
file in the working directory based on `misc/example.env`.

```bash
helpdeskbot
# or
python -m helpdeskbot
```

## Contact

nanodano@devdungeon.com
